@@ -4,6 +4,7 @@
 
 use crate::event::{Event, Key, KeyEvent};
 use crate::listener::{ListenerResult, Poll};
+use crate::{AttrValue, Attribute, Injector};
 
 use std::marker::PhantomData;
 
@@ -71,3 +72,20 @@ pub enum MockMsg {
     BarSubmit(String),
     BarTick,
 }
+
+// -- injector
+
+#[derive(Default)]
+pub struct MockInjector;
+
+impl Injector<MockComponentId> for MockInjector {
+    fn inject(&self, id: &MockComponentId) -> Vec<(Attribute, AttrValue)> {
+        match id {
+            &MockComponentId::InputBar => vec![(
+                Attribute::Text,
+                AttrValue::String(String::from("hello, world!")),
+            )],
+            _ => vec![],
+        }
+    }
+}
